# JournalEntryItemType

Type of Journal Entry Item.

## Enum

* `CREDIT` (value: `'Credit'`)

* `DEBIT` (value: `'Debit'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


